@@ -595,7 +595,7 @@ class HOD(object):
                 for i, r in enumerate(self.r):
                     power = self.power_gal_2h(i)
                     fit = spline(self.pert.lnk, np.log(power))
-                    self.__corr_gal_2h[i] = tools.power_to_corr(fit, self.r)
+                    self.__corr_gal_2h[i] = tools.power_to_corr(fit, r)
 #                     self.__corr_gal_2h[i] = fort.power_to_corr(nlnk=len(self.pert.lnk),
 #                                                                nr=len(self.r),
 #                                                                lnk=self.pert.lnk,
